@@ -20,6 +20,7 @@ def Help():
                  run_at_build: bool = False, sun_icon: str = 'white-balance-sunny',
                  moon_icon: str = 'weather-night', main_color: str = 'Blue''')
 
+
 def Spec(name: str, filename: str, icon: str, path: str = os.getcwd()):
 
     path = path.replace("\\", r"\\")
@@ -74,28 +75,31 @@ coll = COLLECT(exe, Tree('{path}'),
                upx_exclude=[],
                name='{name}')""")
 
+
 class Kivy4(MDApp):
 
-    def __init__(self, builder_string: str = '', app_name: str = '', list_of_files: list = None,
+    dark_mode_icon = StringProperty('')
+
+    def __init__(self, string: str = '', app_name: str = '', list_of_files: list = None,
                  screen_size=None, min_x: int = 0.1, min_y: int = 0.1, center: bool = True,
                  run_at_build: bool = False, sun_icon: str = 'white-balance-sunny',
-                 moon_icon: str = 'weather-night', main_color: str = 'Blue', **kwargs):
+                 moon_icon: str = 'weather-night', main_color: str = 'Blue', icon: str = '',
+                 toolbar = False, custom_classes: bool = True, disable_x: bool = False, **kwargs):
 
         super().__init__(**kwargs)
 
-        self.builder_string = builder_string
         self.app_name = app_name
 
         app_data_path = os.getenv('APPDATA') + '/' + app_name
         self.appdata_path = app_data_path
-        # self.appdata_path = app_name
         self.create_files(list_of_files)
 
+        self.icon = icon
         self.moon_icon = moon_icon
         self.sun_icon = sun_icon
-        self.dark_mode_icon = StringProperty(sun_icon)
         self.isDarkMode()
         self.theme_cls.primary_palette = main_color
+        self.disable_x = disable_x
 
         screen = get_monitors()[0]
         self.width = screen.width
@@ -105,18 +109,29 @@ class Kivy4(MDApp):
 
         self.run_at_build = run_at_build
 
+        self.builder_string = ''
+
+        if custom_classes:
+            self.builder_string += self.custom_classes()
+
+        if toolbar:
+            self.builder_string += self.getToolbar(toolbar)
+            string = '\n            '.join(string.split('\n'))
+
+        self.builder_string += string
+
         self.run()
 
     def build(self):
         self.use_kivy_settings = False
         self.settings_cls = ContentPanel
         self.title = self.app_name
-        Window.bind(on_request_close=lambda x: self.on_request_close())
+        Window.bind(on_request_close=lambda x: self.on_request_close(self.disable_x))
 
         if self.run_at_build:
             self.Build()
 
-        return Builder.load_string(self.custom_classes() + self.builder_string)
+        return Builder.load_string(self.builder_string)
 
     def screen_positions(self, screen_size, min_x, min_y, center):
 
@@ -183,13 +198,7 @@ class Kivy4(MDApp):
             with open(self.appdata_path + '/' + filename, 'r') as f:
 
                 current_mode = f.read()
-                self.theme_cls.theme_style = current_mode
-
-                if f.read() == 'Dark':
-                    self.dark_mode_icon = self.moon_icon
-
-                else:
-                    self.dark_mode_icon = self.sun_icon
+                self.setDarkModeIcon(current_mode)
 
                 return current_mode == 'Dark'
 
@@ -198,13 +207,7 @@ class Kivy4(MDApp):
                 default = darkdetect.theme()
                 f.write(default)
 
-                self.theme_cls.theme_style = default
-
-                if default == 'Dark':
-                    self.dark_mode_icon = self.moon_icon
-
-                else:
-                    self.dark_mode_icon = self.sun_icon
+                self.setDarkModeIcon(default)
 
                 return default == 'Dark'
 
@@ -213,14 +216,7 @@ class Kivy4(MDApp):
             value = darkdetect.theme()
 
         self.setFile(filename, value)
-
-        if value == 'Dark':
-            self.dark_mode_icon = self.moon_icon
-
-        else:
-            self.dark_mode_icon = self.sun_icon
-
-        self.theme_cls.theme_style = value
+        self.setDarkModeIcon(value)
 
     def reverseDarkMode(self, filename: str = 'dark mode.txt'):
         try:
@@ -235,38 +231,50 @@ class Kivy4(MDApp):
                 self.setDarkMode('Dark')
                 return 'Dark'
 
-
         except FileNotFoundError:
             with open(self.appdata_path + '/' + filename, 'w') as f:
                 default = darkdetect.theme()
                 f.write(default)
 
-                self.theme_cls.theme_style = default
-
-                if default == 'Dark':
-                    self.dark_mode_icon = self.moon_icon
-
-                else:
-                    self.dark_mode_icon = self.sun_icon
+                self.setDarkModeIcon(default)
 
                 return default
 
-    @staticmethod
-    def on_request_close(ignore_user_request: bool = False):
-        return ignore_user_request
+    def setDarkModeIcon(self, value):
+        if value == 'Dark':
+            self.dark_mode_icon = self.moon_icon
+
+        else:
+            self.dark_mode_icon = self.sun_icon
+
+        self.theme_cls.theme_style = value
 
     @staticmethod
-    def getToolbar(properties: list):
+    def on_request_close(disable_x: bool = False):
+        return disable_x
+
+    def getToolbar(self, properties: list):
+        if properties == True:
+            properties = ['toolbar', self.app_name, '[]', '[[app.dark_mode_icon, lambda x: self.reverseDarkMode()]]']
+
         Id, title, right_icons, left_icons = properties
 
         return f'''
+Screen:
     MDToolbar:
         id: {Id}
         pos_hint: {{"top": 1}}
         elevation: 10
-        title: {title}
+        title: "{title}"
         right_action_items: {right_icons}
-        left_action_items: {left_icons}'''
+        left_action_items: {left_icons}
+    
+    MDNavigationLayout:
+        x: toolbar.height
+        ScreenManager:
+            id: screen_manager
+'''
+
 
     @staticmethod
     def custom_classes():
